!**********************************************************************
! Copyright 1998-2015                                                 *
! Andreas Stohl, Petra Seibert, A. Frank, Gerhard Wotawa,             *
! Caroline Forster, Sabine Eckhardt, John Burkhart, Harald Sodemann   *
!                                                                     *
! This file is part of FLEXPART.                                      *
!                                                                     *
! FLEXPART is free software: you can redistribute it and/or modify    *
! it under the terms of the GNU General Public License as published by*
! the Free Software Foundation, either version 3 of the License, or   *
! (at your option) any later version.                                 *
!                                                                     *
! FLEXPART is distributed in the hope that it will be useful,         *
! but WITHOUT ANY WARRANTY; without even the implied warranty of      *
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *
! GNU General Public License for more details.                        *
!                                                                     *
! You should have received a copy of the GNU General Public License   *
! along with FLEXPART.  If not, see <http://www.gnu.org/licenses/>.   *
!**********************************************************************

subroutine wetdepokernel(nunc,deposit,x,y,itage,nage,kp)
  !                          i      i    i  i    i   i
  !*****************************************************************************
  !                                                                            *
  !     Attribution of the deposition from an individual particle to the       *
  !     deposition fields using a uniform kernel with bandwidths dxout         *
  !     and dyout.                                                             *
  !                                                                            *
  !     Author: A. Stohl                                                       *
  !                                                                            *
  !     26 December 1996                                                       *
  !
  !  PS, 2/2015: do not use kernel for itage < 3 h
  !   same as for concentration in conccalc.f90
  !                                                                            *
  !*****************************************************************************
  !                                                                            *
  ! Variables:                                                                 *
  !                                                                            *
  ! nunc             uncertainty class of the respective particle              *
  ! nage             age class of the respective particle                      *
  ! deposit          amount (kg) to be deposited                               *
  !                                                                            *
  !*****************************************************************************

  use unc_mod
  use par_mod
  use com_mod

  implicit none

  real :: x,y,deposit(maxspec),ddx,ddy,xl,yl,wx,wy,w
  integer :: ix,jy,ixp,jyp,nunc,nage,ks,kp,itage

  xl=(x*dx+xoutshift)/dxout
  yl=(y*dy+youtshift)/dyout
  ix=int(xl)
  jy=int(yl)
  ddx=xl-real(ix)                   ! distance to left cell border
  ddy=yl-real(jy)                   ! distance to lower cell border

  if (ddx.gt.0.5) then
    ixp=ix+1
    wx=1.5-ddx
  else
    ixp=ix-1
    wx=0.5+ddx
  endif

  if (ddy.gt.0.5) then
    jyp=jy+1
    wy=1.5-ddy
  else
    jyp=jy-1
    wy=0.5+ddy
  endif


  if (itage .lt. itagekernmin) then 
    ! no kernel, direct attribution to grid cell
    
    do ks=1,nspec
      if (ix.ge.0 .and. jy.ge.0 .and. &
          ix.le.numxgrid-1 .and. jy.le.numygrid-1) &
        wetgridunc(ix,jy,ks,kp,nunc,nage)= &
          wetgridunc(ix,jy,ks,kp,nunc,nage)+deposit(ks)
    enddo
        
  else
    ! Determine mass fractions for four grid points & distribute

    do ks=1,nspec

      if (ix.ge.0 .and. jy.ge.0 .and. &
          ix.le.numxgrid-1 .and. jy.le.numygrid-1) then
        w=wx*wy
        wetgridunc(ix,jy,ks,kp,nunc,nage)= &
          wetgridunc(ix,jy,ks,kp,nunc,nage)+deposit(ks)*w
      endif

      if ((ixp.ge.0).and.(jyp.ge.0).and.&
         (ixp.le.numxgrid-1).and. (jyp.le.numygrid-1)) then
        w=(1.-wx)*(1.-wy)
        wetgridunc(ixp,jyp,ks,kp,nunc,nage)= &
          wetgridunc(ixp,jyp,ks,kp,nunc,nage)+deposit(ks)*w
      endif

      if ((ixp.ge.0).and.(jy.ge.0).and. &
          (ixp.le.numxgrid-1).and.(jy.le.numygrid-1)) then
        w=(1.-wx)*wy
        wetgridunc(ixp,jy,ks,kp,nunc,nage)= &
           wetgridunc(ixp,jy,ks,kp,nunc,nage)+deposit(ks)*w
      endif

      if ((ix.ge.0).and.(jyp.ge.0).and. &
          (ix.le.numxgrid-1).and.(jyp.le.numygrid-1)) then
        w=wx*(1.-wy)
        wetgridunc(ix,jyp,ks,kp,nunc,nage)= &
          wetgridunc(ix,jyp,ks,kp,nunc,nage)+deposit(ks)*w
      endif

    end do

  endif

end subroutine wetdepokernel
